import PanelViewShow from './views/panel/list/index'
import PreviewCom from './components/canvas/components/Editor/index'

// 模块vuex
import user from './store/modules/user'
import chart from './store/modules/chart'
import panel from './store/modules/panel'
import map from './store/modules/map'
import report from './store/modules/report'

import '@/styles/index.scss' // global css
// 移动端用
import ElementUI from 'element-ui'
import message from './utils/message'
import widgets from '@/components/widget'
import Picture from '@/components/canvas/custom-component/Picture'
import VText from '@/components/canvas/custom-component/VText'
import VButton from '@/components/canvas/custom-component/VButton'
import Group from '@/components/canvas/custom-component/Group'
import RectShape from '@/components/canvas/custom-component/RectShape'
import UserView from '@/components/canvas/custom-component/UserView'
import DeVideo from '@/components/canvas/custom-component/DeVideo'
import * as echarts from 'echarts'
import fullscreen from 'vue-fullscreen'
import directives from './directive'

const components = [
  PanelViewShow,
  ...PreviewCom,
  Picture,
  VText,
  VButton,
  Group,
  RectShape,
  UserView,
  DeVideo
]

const install = function(Vue, opts = {}) {
  if (!opts.store) {
    console.log('Please provide a store!')
  }
  // 移动端用
  Vue.use(ElementUI)
  Vue.prototype.$echarts = echarts
  Vue.use(message)
  Vue.use(widgets)
  Vue.use(fullscreen)
  Vue.use(directives)
  components.map(component => {
    Vue.component(component.name, component)
  })
  // 动态注册store
  opts.store.registerModule('user', user)
  opts.store.registerModule('chart', chart)
  opts.store.registerModule('panel', panel)
  opts.store.registerModule('map', map)
  opts.store.registerModule('report', report)
}

/* 支持使用标签的方式引入 */
if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue)
}

export default {
  install,
  ...components
}

